==> create-fly-1.21.10-6.0.8-5-sources.jar: com/zurrtum/create/infrastructure/packet/c2s/ConfigureWorldshaperPacket.java <==
package com.zurrtum.create.infrastructure.packet.c2s;

import com.zurrtum.create.AllHandle;
import com.zurrtum.create.AllPackets;
import com.zurrtum.create.catnip.codecs.stream.CatnipLargerStreamCodecs;
import com.zurrtum.create.catnip.codecs.stream.CatnipStreamCodecs;
import com.zurrtum.create.content.equipment.zapper.ConfigureZapperPacket;
import com.zurrtum.create.content.equipment.zapper.terrainzapper.WorldshaperItem;
import com.zurrtum.create.infrastructure.component.PlacementOptions;
import com.zurrtum.create.infrastructure.component.PlacementPatterns;
import com.zurrtum.create.infrastructure.component.TerrainBrushes;
import com.zurrtum.create.infrastructure.component.TerrainTools;
import io.netty.buffer.ByteBuf;
import net.minecraft.class_1268;
import net.minecraft.class_1799;
import net.minecraft.class_2792;
import net.minecraft.class_3244;
import net.minecraft.class_9135;
import net.minecraft.class_9139;
import net.minecraft.class_9145;

public record ConfigureWorldshaperPacket(
    class_1268 hand, PlacementPatterns pattern, TerrainBrushes brush, int brushParamX, int brushParamY, int brushParamZ, TerrainTools tool,
    PlacementOptions placement
) implements ConfigureZapperPacket {
    public static final class_9139<ByteBuf, ConfigureWorldshaperPacket> CODEC = CatnipLargerStreamCodecs.composite(
        CatnipStreamCodecs.HAND,
        packet -> packet.hand,
        PlacementPatterns.STREAM_CODEC,
        packet -> packet.pattern,
        TerrainBrushes.STREAM_CODEC,
        packet -> packet.brush,
        class_9135.field_48550,
        packet -> packet.brushParamX,
        class_9135.field_48550,
        packet -> packet.brushParamY,
        class_9135.field_48550,
        packet -> packet.brushParamZ,
        TerrainTools.STREAM_CODEC,
        packet -> packet.tool,
        PlacementOptions.STREAM_CODEC,
        packet -> packet.placement,
        ConfigureWorldshaperPacket::new
    );

    @Override
    public void configureZapper(class_1799 stack) {
        WorldshaperItem.configureSettings(stack, pattern, brush, brushParamX, brushParamY, brushParamZ, tool, placement);
    }

    @Override
    public void apply(class_2792 listener) {
        AllHandle.onConfigureWorldshaper((class_3244) listener, this);
    }

    @Override
    public class_9145<ConfigureWorldshaperPacket> method_65080() {
        return AllPackets.CONFIGURE_WORLDSHAPER;
    }
}

==> create-fly-1.21.11-pre1-6.0.8-1-sources.jar: com/zurrtum/create/infrastructure/packet/c2s/ConfigureWorldshaperPacket.java <==
package com.zurrtum.create.infrastructure.packet.c2s;

import com.zurrtum.create.AllHandle;
import com.zurrtum.create.AllPackets;
import com.zurrtum.create.catnip.codecs.stream.CatnipLargerStreamCodecs;
import com.zurrtum.create.catnip.codecs.stream.CatnipStreamCodecs;
import com.zurrtum.create.content.equipment.zapper.ConfigureZapperPacket;
import com.zurrtum.create.content.equipment.zapper.terrainzapper.WorldshaperItem;
import com.zurrtum.create.infrastructure.component.PlacementOptions;
import com.zurrtum.create.infrastructure.component.PlacementPatterns;
import com.zurrtum.create.infrastructure.component.TerrainBrushes;
import com.zurrtum.create.infrastructure.component.TerrainTools;
import io.netty.buffer.ByteBuf;

import java.util.function.BiConsumer;
import net.minecraft.class_1268;
import net.minecraft.class_1799;
import net.minecraft.class_3244;
import net.minecraft.class_9135;
import net.minecraft.class_9139;
import net.minecraft.class_9145;

public record ConfigureWorldshaperPacket(
    class_1268 hand, PlacementPatterns pattern, TerrainBrushes brush, int brushParamX, int brushParamY, int brushParamZ, TerrainTools tool,
    PlacementOptions placement
) implements ConfigureZapperPacket {
    public static final class_9139<ByteBuf, ConfigureWorldshaperPacket> CODEC = CatnipLargerStreamCodecs.composite(
        CatnipStreamCodecs.HAND,
        packet -> packet.hand,
        PlacementPatterns.STREAM_CODEC,
        packet -> packet.pattern,
        TerrainBrushes.STREAM_CODEC,
        packet -> packet.brush,
        class_9135.field_48550,
        packet -> packet.brushParamX,
        class_9135.field_48550,
        packet -> packet.brushParamY,
        class_9135.field_48550,
        packet -> packet.brushParamZ,
        TerrainTools.STREAM_CODEC,
        packet -> packet.tool,
        PlacementOptions.STREAM_CODEC,
        packet -> packet.placement,
        ConfigureWorldshaperPacket::new
    );

    @Override
    public void configureZapper(class_1799 stack) {
        WorldshaperItem.configureSettings(stack, pattern, brush, brushParamX, brushParamY, brushParamZ, tool, placement);
    }

    @Override
    public class_9145<ConfigureWorldshaperPacket> method_65080() {
        return AllPackets.CONFIGURE_WORLDSHAPER;
    }

    @Override
    public BiConsumer<class_3244, ConfigureWorldshaperPacket> callback() {
        return AllHandle::onConfigureWorldshaper;
    }
}
